////////////////////////////////////////////////////////////
//
// SFML - Simple and Fast Multimedia Library
// Copyright (C) 2007-2009 Laurent Gomila (laurent.gom@gmail.com)
//
// This software is provided 'as-is', without any express or implied warranty.
// In no event will the authors be held liable for any damages arising from the use of this software.
//
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it freely,
// subject to the following restrictions:
//
// 1. The origin of this software must not be misrepresented;
//    you must not claim that you wrote the original software.
//    If you use this software in a product, an acknowledgment
//    in the product documentation would be appreciated but is not required.
//
// 2. Altered source versions must be plainly marked as such,
//    and must not be misrepresented as being the original software.
//
// 3. This notice may not be removed or altered from any source distribution.
//
////////////////////////////////////////////////////////////

#ifndef SFML_JOYSTICK_HPP
#define SFML_JOYSTICK_HPP

////////////////////////////////////////////////////////////
// Headers
////////////////////////////////////////////////////////////
#include <SFML/Config.hpp>
#include <SFML/Window/Event.hpp>


namespace sf
{
namespace priv
{
////////////////////////////////////////////////////////////
/// Structure holding the joystick state's parameters
////////////////////////////////////////////////////////////
struct JoystickState
{
    JoystickState()
    {
        // Default value for axes
        for (int i = 0; i < Joy::AxisCount; ++i)
            Axis[i] = 0.f;
        Axis[Joy::AxisPOV] = -1.f;

        // Default value for buttons
        for (int i = 0; i < Joy::ButtonCount; ++i)
            Buttons[i] = false;
    }

    float Axis[Joy::AxisCount];      ///< Position on each axis in range [-100, 100] (except POV which is [0, 360])
    bool  Buttons[Joy::ButtonCount]; ///< Status of each button (true = pressed)
};

} // namespace priv

} // namespace sf


#if defined(SFML_SYSTEM_WINDOWS)

    #include <SFML/Window/Win32/Joystick.hpp>

#elif defined(SFML_SYSTEM_LINUX) || defined(SFML_SYSTEM_FREEBSD)

    #include <SFML/Window/Linux/Joystick.hpp>

#elif defined(SFML_SYSTEM_MACOS)

	#include <SFML/Window/Cocoa/Joystick.hpp>

#endif


#endif // SFML_JOYSTICK_HPP
